@@ -5,12 +5,18 @@ This is meant to be executed as a subprocess of testflo.
 """
 
 if __name__ == '__main__':
+    try:
+        import coverage
+    except ImportError:
+        coverage = None
+    else:
+        coverage.process_startup()
+
     import sys
     import os
     import traceback
 
     from testflo.test import Test
-    from testflo.cover import save_coverage
     from testflo.qman import get_client_queue
     from testflo.options import get_options
 
@@ -29,8 +35,6 @@ if __name__ == '__main__':
             test.status = 'FAIL'
             test.err_msg = traceback.format_exc()
 
-        save_coverage()
-
     except:
         test.err_msg = traceback.format_exc()
         test.status = 'FAIL'
